@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 name = 'moment'
-version = '0.7'
+version = '0.9'
 website = 'https://github.com/lepture/liquidluck-theme-moment'
 author = {
     'name': 'Hsiaoming Yang',
@@ -9,15 +9,21 @@ author = {
 }
 
 
-show_author = False
+lang = 'en'
 tagcloud = False
+
 navigation = [
     ('Home', '/'),
     ('About', '/about.html'),
 ]
 
-lang = 'en'
 twitter = 'lepture'
 github = None
 disqus = None
 analytics = None
+
+allow_comment_on_secret_post = False
+
+
+#: key-value descriptions
+descriptions = {}
