@@ -121,7 +121,11 @@ def run_parser(args):
         return
 
     if args.subparser == 'server':
-        generator.load_settings(args.settings)
+        if not os.path.exists(args.settings):
+            print('setting file not found')
+            g.output_directory = os.path.abspath('.')
+        else:
+            generator.load_settings(args.settings)
         if settings.permalink.endswith('.html'):
             permalink = 'html'
         elif settings.permalink.endswith('/'):
