@@ -22,7 +22,8 @@ from liquidluck.options import settings
 
 # liquidluck settings
 from liquidluck.options import g
-from liquidluck.filters import xmldatetime
+from liquidluck.filters import xmldatetime, feed_updated
+from liquidluck.filters import tag_url, year_url
 
 
 class BaseWriter(object):
@@ -209,7 +210,10 @@ def load_jinja():
     #: default filters
     jinja.filters.update({
         'xmldatetime': xmldatetime,
+        'feed_updated': feed_updated,
         'permalink': permalink,
+        'tag_url': tag_url,
+        'year_url': year_url,
     })
 
     #: load resource
